import dom from '../../dom';
import { getFirstByXPath, getXPathForElement } from './xpath';
export const discriminator = 'XpathRangeSelector';
export function serialize(range, referenceElement) {
    referenceElement = referenceElement || dom(range.commonAncestorContainer).closest('[id]');
    if (!referenceElement) {
        throw new Error('reference element not found');
    }
    const [endContainer, endOffset] = getXPathForElement(range.endContainer, range.endOffset, referenceElement);
    const [startContainer, startOffset] = getXPathForElement(range.startContainer, range.startOffset, referenceElement);
    return {
        endContainer,
        endOffset,
        referenceElementId: referenceElement.id,
        startContainer,
        startOffset,
        type: discriminator,
    };
}
export function isLoadable(highlighter, data) {
    const referenceElement = highlighter.getReferenceElement(data.referenceElementId);
    if (!referenceElement) {
        return false;
    }
    const [startContainer] = getFirstByXPath(data.startContainer, data.startOffset, referenceElement);
    const [endContainer] = getFirstByXPath(data.endContainer, data.endOffset, referenceElement);
    return !!startContainer && !!endContainer;
}
export function load(highlighter, data) {
    const range = highlighter.document.createRange();
    const referenceElement = highlighter.getReferenceElement(data.referenceElementId);
    const [startContainer, startOffset] = getFirstByXPath(data.startContainer, data.startOffset, referenceElement);
    const [endContainer, endOffset] = getFirstByXPath(data.endContainer, data.endOffset, referenceElement);
    range.setStart(startContainer, startOffset);
    range.setEnd(endContainer, endOffset);
    return range;
}
//# sourceMappingURL=index.js.map